@@ -26,12 +26,10 @@ eval {
 
     sub new {
 	my $class = shift;
-	LWP::Debug::trace('()');
 
 	my $self = $class->SUPER::new(@_) || return undef;
 
 	my $mess = $self->message;  # welcome message
-	LWP::Debug::debug($mess);
 	$mess =~ s|\n.*||s; # only first line left
 	$mess =~ s|\s*ready\.?$||;
 	# Make the version number more HTTP like
@@ -57,7 +55,6 @@ eval {
     }
 
     sub go_home {
-	LWP::Debug::trace('');
 	my $self = shift;
 	$self->cwd(${*$self}{myftp_home});
     }
@@ -68,7 +65,6 @@ eval {
     }
 
     sub ping {
-	LWP::Debug::trace('');
 	my $self = shift;
 	return $self->go_home;
     }
@@ -87,7 +83,6 @@ sub _connect {
 	$key .= ":$account" if defined($account);
 	if (my $ftp = $conn_cache->withdraw("ftp", $key)) {
 	    if ($ftp->ping) {
-		LWP::Debug::debug('Reusing old connection');
 		# save it again
 		$conn_cache->deposit("ftp", $key, $ftp);
 		return $ftp;
@@ -106,21 +101,17 @@ sub _connect {
 	return HTTP::Response->new(&HTTP::Status::RC_INTERNAL_SERVER_ERROR, $@);
     }
 
-    LWP::Debug::debug("Logging in as $user (password $password)...");
     unless ($ftp->login($user, $password, $account)) {
 	# Unauthorized.  Let's fake a RC_UNAUTHORIZED response
 	my $mess = scalar($ftp->message);
-	LWP::Debug::debug($mess);
 	$mess =~ s/\n$//;
 	my $res =  HTTP::Response->new(&HTTP::Status::RC_UNAUTHORIZED, $mess);
 	$res->header("Server", $ftp->http_server);
 	$res->header("WWW-Authenticate", qq(Basic Realm="FTP login"));
 	return $res;
     }
-    LWP::Debug::debug($ftp->message);
 
     my $home = $ftp->pwd;
-    LWP::Debug::debug("home: '$home'");
     $ftp->home($home);
 
     $conn_cache->deposit("ftp", $key, $ftp) if $conn_cache;
@@ -135,8 +126,6 @@ sub request
 
     $size = 4096 unless $size;
 
-    LWP::Debug::trace('()');
-
     # check proxy
     if (defined $proxy)
     {
@@ -214,7 +203,6 @@ sub request
     }
 
     for (@path) {
-	LWP::Debug::debug("CWD $_");
 	unless ($ftp->cwd($_)) {
 	    return HTTP::Response->new(&HTTP::Status::RC_NOT_FOUND,
 				       "Can't chdir to $_");
@@ -222,7 +210,6 @@ sub request
     }
 
     if ($method eq 'GET' || $method eq 'HEAD') {
-	LWP::Debug::debug("MDTM");
 	if (my $mod_time = $ftp->mdtm($remote_file)) {
 	    $response->last_modified($mod_time);
 	    if (my $ims = $request->if_modified_since) {
@@ -272,7 +259,6 @@ sub request
 	}
 
 	my $data;  # the data handle
-	LWP::Debug::debug("retrieve file?");
 	if (length($remote_file) and $data = $ftp->retr($remote_file)) {
 	    my($type, @enc) = LWP::MediaTypes::guess_media_type($remote_file);
 	    $response->header('Content-Type',   $type) if $type;
@@ -280,7 +266,6 @@ sub request
 		$response->push_header('Content-Encoding', $_);
 	    }
 	    my $mess = $ftp->message;
-	    LWP::Debug::debug($mess);
 	    if ($mess =~ /\((\d+)\s+bytes\)/) {
 		$response->header('Content-Length', "$1");
 	    }
@@ -336,13 +321,11 @@ sub request
 	elsif (!length($remote_file) || ( $ftp->code >= 400 && $ftp->code < 600 )) {
 	    # not a plain file, try to list instead
 	    if (length($remote_file) && !$ftp->cwd($remote_file)) {
-		LWP::Debug::debug("chdir before listing failed");
 		return HTTP::Response->new(&HTTP::Status::RC_NOT_FOUND,
 					   "File '$remote_file' not found");
 	    }
 
 	    # It should now be safe to try to list the directory
-	    LWP::Debug::debug("dir");
 	    my @lsl = $ftp->dir;
 
 	    # Try to figure out if the user want us to convert the
@@ -404,8 +387,6 @@ sub request
 	}
 	my $data;
 	if ($data = $ftp->stor($remote_file)) {
-	    LWP::Debug::debug($ftp->message);
-	    LWP::Debug::debug("$data");
 	    my $content = $request->content;
 	    my $bytes = 0;
 	    if (defined $content) {
@@ -430,7 +411,6 @@ sub request
 		}
 	    }
 	    $data->close;
-	    LWP::Debug::debug($ftp->message);
 
 	    $response->code(&HTTP::Status::RC_CREATED);
 	    $response->header('Content-Type', 'text/plain');
